"use strict";

exports.__esModule = true;
exports.default = memoize;

var _LRUCache = _interopRequireDefault(require("./LRUCache"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function memoize(size, opt) {
  if (size === void 0) {
    size = 1;
  }

  if (opt === void 0) {
    opt = {
      coalesceWith: void 0,
      multiArgs: false
    };
  }

  var cache = (0, _LRUCache.default)(size, opt.multiArgs);
  return function (fn) {
    return function () {
      var key;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      if (args.length > 1) {
        if (opt.coalesceWith !== void 0) {
          key = opt.coalesceWith(args);
        } else {
          key = args;
        }
      } else {
        key = args[0];
      }

      var item = cache.get(key);

      if (item === void 0) {
        item = fn.apply(void 0, args);
        cache.set(key, item);
      }

      return item;
    };
  };
}